package com.taais.demo.mapper;

import com.taais.demo.domain.DemoProduct;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 产品树表（mb）Mapper接口
 *
 * @author wgk
 * 2023-07-11
 */
@Mapper
public interface DemoProductMapper {
    /**
     * 查询产品树表（mb）
     *
     * @param productId 产品树表（mb）主键
     * @return 产品树表（mb）
     */
    DemoProduct selectDemoProductByProductId(Long productId);

    /**
     * 查询产品树表（mb）列表
     *
     * @param demoProduct 产品树表（mb）
     * @return 产品树表（mb）集合
     */
    List<DemoProduct> selectDemoProductList(DemoProduct demoProduct);

    /**
     * 新增产品树表（mb）
     *
     * @param demoProduct 产品树表（mb）
     * @return 结果
     */
    int insertDemoProduct(DemoProduct demoProduct);

    /**
     * 修改产品树表（mb）
     *
     * @param demoProduct 产品树表（mb）
     * @return 结果
     */
    int updateDemoProduct(DemoProduct demoProduct);

    /**
     * 删除产品树表（mb）
     *
     * @param productId 产品树表（mb）主键
     * @return 结果
     */
    int deleteDemoProductByProductId(Long productId);

    /**
     * 批量删除产品树表（mb）
     *
     * @param productIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteDemoProductByProductIds(Long[] productIds);
}
